/*
 * ConnectBot: simple, powerful, open-source SSH client for Android
 * Copyright 2010 Kenny Root, Jeffrey Sharkey
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.five_ten_sg.connectbot.service;

import com.five_ten_sg.connectbot.ConsoleActivity;
import com.five_ten_sg.connectbot.R;
import com.five_ten_sg.connectbot.bean.HostBean;
import com.five_ten_sg.connectbot.util.HostDatabase;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.Color;

/**
 * @author Kenny Root
 *
 * Based on the concept from jasta's blog post.
 */
public class ConnectionNotifier {
    private static final int ONLINE_NOTIFICATION = 1;
    private static final int ACTIVITY_NOTIFICATION = 2;

    protected NotificationManager getNotificationManager(Context context) {
        return (NotificationManager)context.getSystemService(Context.NOTIFICATION_SERVICE);
    }

    protected Notification newNotification(Context context) {
        Notification notification = new Notification();
        notification.icon = R.drawable.notification_icon;
        notification.when = System.currentTimeMillis();
        return notification;
    }

    protected Notification newActivityNotification(Context context, HostBean host) {
        Notification notification = newNotification(context);
        Resources res = context.getResources();
        String contentText = res.getString(
                                 R.string.notification_text, host.getNickname());
        Intent notificationIntent = new Intent(context, ConsoleActivity.class);
        notificationIntent.setAction(Intent.ACTION_VIEW);
        notificationIntent.setData(host.getUri());
        PendingIntent contentIntent = PendingIntent.getActivity(context, 0,
                                      notificationIntent, 0);
        notification.setLatestEventInfo(context, res.getString(R.string.app_name), contentText, contentIntent);
        notification.flags = Notification.FLAG_AUTO_CANCEL;
        notification.flags |= Notification.DEFAULT_LIGHTS;

        if (HostDatabase.COLOR_RED.equals(host.getColor()))
            notification.ledARGB = Color.RED;
        else if (HostDatabase.COLOR_GREEN.equals(host.getColor()))
            notification.ledARGB = Color.GREEN;
        else if (HostDatabase.COLOR_BLUE.equals(host.getColor()))
            notification.ledARGB = Color.BLUE;
        else
            notification.ledARGB = Color.WHITE;

        notification.ledOnMS = 300;
        notification.ledOffMS = 1000;
        notification.flags |= Notification.FLAG_SHOW_LIGHTS;
        return notification;
    }

    protected Notification newRunningNotification(Context context) {
        Notification notification = newNotification(context);
        notification.flags = Notification.FLAG_ONGOING_EVENT
                             | Notification.FLAG_NO_CLEAR;
        notification.when = 0;
        notification.contentIntent = PendingIntent.getActivity(context,
                                     ONLINE_NOTIFICATION,
                                     new Intent(context, ConsoleActivity.class), 0);
        Resources res = context.getResources();
        notification.setLatestEventInfo(context,
                                        res.getString(R.string.app_name),
                                        res.getString(R.string.app_is_running),
                                        notification.contentIntent);
        return notification;
    }

    public void showActivityNotification(Service context, HostBean host) {
        getNotificationManager(context).notify(ACTIVITY_NOTIFICATION, newActivityNotification(context, host));
    }

    public void hideActivityNotification(Service context) {
        getNotificationManager(context).cancel(ACTIVITY_NOTIFICATION);
    }

    public void showRunningNotification(Service context) {
        context.startForeground(ONLINE_NOTIFICATION, newRunningNotification(context));
    }

    public void hideRunningNotification(Service context) {
        context.stopForeground(true);
    }
}
